==> quantlib_1.9.1.orig.tar.gz: QuantLib-1.9.1/test-suite/fdheston.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2008 Klaus Spanderen
 Copyright (C) 2014 Johannes Göttker-Schnetmann

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_test_fd_heston_hpp
#define quantlib_test_fd_heston_hpp

#include <boost/test/unit_test.hpp>

/* remember to document new and/or updated tests in the Doxygen
   comment block of the corresponding class */

class FdHestonTest {
public:
    static void testFdmHestonBarrier();
    static void testFdmHestonBarrierVsBlackScholes();
    static void testFdmHestonAmerican();
    static void testFdmHestonIkonenToivanen();
    static void testFdmHestonEuropeanWithDividends();
    static void testFdmHestonConvergence();
    static void testFdmHestonBlackScholes();
    static void testFdmHestonIntradayPricing();

    static boost::unit_test_framework::test_suite* suite();
};

#endif

==> quantlib_1.12.orig.tar.gz: QuantLib-1.12/test-suite/fdheston.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2008 Klaus Spanderen
 Copyright (C) 2014 Johannes Göttker-Schnetmann

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_test_fd_heston_hpp
#define quantlib_test_fd_heston_hpp

#include <boost/test/unit_test.hpp>
#include "speedlevel.hpp"

/* remember to document new and/or updated tests in the Doxygen
   comment block of the corresponding class */

class FdHestonTest {
public:
    static void testFdmHestonBarrier();
    static void testFdmHestonBarrierVsBlackScholes();
    static void testFdmHestonAmerican();
    static void testFdmHestonIkonenToivanen();
    static void testFdmHestonEuropeanWithDividends();
    static void testFdmHestonConvergence();
    static void testFdmHestonBlackScholes();
    static void testFdmHestonIntradayPricing();

    static boost::unit_test_framework::test_suite* suite(SpeedLevel);
};

#endif
